==> aria2_0.12.1.orig.tar.gz: aria2-0.12.1/src/SingleFileAllocationIterator.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_SINGLE_FILE_ALLOCATION_ITERATOR_H_
#define _D_SINGLE_FILE_ALLOCATION_ITERATOR_H_

#include "FileAllocationIterator.h"

class BinaryStream;

class SingleFileAllocationIterator:public FileAllocationIterator
{
private:
  BinaryStream* _stream;

  int64_t _offset;

  int64_t _totalLength;

  unsigned char* _buffer;
public:
  SingleFileAllocationIterator(BinaryStream* stream, int64_t offset, int64_t totalLength);

  virtual ~SingleFileAllocationIterator();

  virtual void allocateChunk();
  
  virtual bool finished();

  virtual int64_t getCurrentLength()
  {
    return _offset;
  }

  virtual int64_t getTotalLength()
  {
    return _totalLength;
  }

  /**
   * Must be called only once, before calling allocateChunk()
   */
  void init();
};

typedef SharedHandle<SingleFileAllocationIterator> SingleFileAllocationIteratorHandle;

#endif // _D_SINGLE_FILE_ALLOCATION_ITERATOR_H_

==> aria2_1.10.0.orig.tar.gz: aria2-1.10.0/src/SingleFileAllocationIterator.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_SINGLE_FILE_ALLOCATION_ITERATOR_H_
#define _D_SINGLE_FILE_ALLOCATION_ITERATOR_H_

#include "FileAllocationIterator.h"

namespace aria2 {

class BinaryStream;

class SingleFileAllocationIterator:public FileAllocationIterator
{
private:
  BinaryStream* stream_;

  off_t offset_;

  uint64_t totalLength_;

  unsigned char* buffer_;
public:
  SingleFileAllocationIterator(BinaryStream* stream, off_t offset, uint64_t totalLength);

  virtual ~SingleFileAllocationIterator();

  virtual void allocateChunk();
  
  virtual bool finished();

  virtual off_t getCurrentLength()
  {
    return offset_;
  }

  virtual uint64_t getTotalLength()
  {
    return totalLength_;
  }

  /**
   * Must be called only once, before calling allocateChunk()
   */
  void init();
};

} // namespace aria2

#endif // _D_SINGLE_FILE_ALLOCATION_ITERATOR_H_
